API
===

.. contents::
    :local:
    :backlinks: none


cabinetry.configuration
-----------------------

.. automodule:: cabinetry.configuration
    :members:


cabinetry.route
---------------

.. automodule:: cabinetry.route
    :members:


cabinetry.histo
---------------

.. automodule:: cabinetry.histo
    :members:


cabinetry.template_builder
--------------------------

.. automodule:: cabinetry.template_builder
    :members:


cabinetry.template_postprocessor
--------------------------------

.. automodule:: cabinetry.template_postprocessor
    :members:


cabinetry.workspace
-------------------

.. automodule:: cabinetry.workspace
    :members:


cabinetry.fit
-------------

.. automodule:: cabinetry.fit
    :members:


cabinetry.visualize
-------------------

.. automodule:: cabinetry.visualize
    :members:


cabinetry.model_utils
---------------------

.. automodule:: cabinetry.model_utils
    :members:


cabinetry.contrib
-----------------

.. automodule:: cabinetry.contrib

.. automodule:: cabinetry.contrib.histogram_creation
    :members:

.. automodule:: cabinetry.contrib.matplotlib_visualize
    :members:
